# mypy-boto3-kafka

[![PyPI - mypy-boto3-kafka](https://img.shields.io/pypi/v/mypy-boto3-kafka.svg?color=blue)](https://pypi.org/project/mypy-boto3-kafka)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-kafka.svg?color=blue)](https://pypi.org/project/mypy-boto3-kafka)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.Kafka 1.14.54](https://boto3.amazonaws.com/v1/documentation/api/1.14.54/reference/services/kafka.html#Kafka) service
compatible with
[VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright)
and other tools.

Generated by [mypy-boto3-buider 3.0.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

- [mypy-boto3-kafka](#mypy-boto3-kafka)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Waiters annotations](#waiters-annotations)
    - [Service Resource annotations](#service-resource-annotations)
    - [Other resources annotations](#other-resources-annotations)
    - [Collections annotations](#collections-annotations)
    - [Typed dictionations](#typed-dictionations)

## How to install

Install `boto3-stubs` for `Kafka` service.

```bash
python -m pip install boto3-stubs[kafka]
```

## Usage

### VSCode

- Install [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[kafka]` in your environment: `python -m pip install 'boto3-stubs[kafka]'`

Both type checking and auto-complete should work for `Kafka` service.
No explicit type annotations required, write your `boto3` code as usual.

### PyCharm

- Install `boto-stubs[kafka]` in your environment: `python -m pip install 'boto3-stubs[kafka]'`

Both type checking and auto-complete should work for `Kafka` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed `boto3-stubs` submodules.

### Other IDEs

Not tested, but as long as your IDE support `mypy` or `pyright`, everything should work.

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[kafka]` in your environment: `python -m pip install 'boto3-stubs[kafka]'`
- Run `mypy` as usual

Type checking should work for `Kafka` service.
No explicit type annotations required, write your `boto3` code as usual.

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[kafka]` in your environment: `python -m pip install 'boto3-stubs[kafka]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `Kafka` service.
No explicit type annotations required, write your `boto3` code as usual.

## Explicit type annotations

### Client annotations

`KafkaClient` provides annotations for `boto3.client("kafka")`.

```python
import boto3

from mypy_boto3_kafka import KafkaClient

client: KafkaClient = boto3.client("kafka")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: KafkaClient = session.client("kafka")
```

### Paginators annotations

`mypy_boto3_kafka.paginator` module contains type annotations for all paginators.

```python
from mypy_boto3_kafka import KafkaClient
from mypy_boto3_kafka.paginator import (
    ListClusterOperationsPaginator,
    ListClustersPaginator,
    ListConfigurationRevisionsPaginator,
    ListConfigurationsPaginator,
    ListKafkaVersionsPaginator,
    ListNodesPaginator,
)

client: KafkaClient = boto3.client("kafka")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_cluster_operations_paginator: ListClusterOperationsPaginator = client.get_paginator("list_cluster_operations")
list_clusters_paginator: ListClustersPaginator = client.get_paginator("list_clusters")
list_configuration_revisions_paginator: ListConfigurationRevisionsPaginator = client.get_paginator("list_configuration_revisions")
list_configurations_paginator: ListConfigurationsPaginator = client.get_paginator("list_configurations")
list_kafka_versions_paginator: ListKafkaVersionsPaginator = client.get_paginator("list_kafka_versions")
list_nodes_paginator: ListNodesPaginator = client.get_paginator("list_nodes")
```







### Typed dictionations

`mypy_boto3_kafka.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_kafka.type_defs import (
    BrokerEBSVolumeInfoTypeDef,
    BrokerLogsTypeDef,
    BrokerNodeGroupInfoTypeDef,
    BrokerNodeInfoTypeDef,
    BrokerSoftwareInfoTypeDef,
    ClientAuthenticationTypeDef,
    CloudWatchLogsTypeDef,
    ClusterInfoTypeDef,
    ClusterOperationInfoTypeDef,
    ClusterOperationStepInfoTypeDef,
    ClusterOperationStepTypeDef,
    CompatibleKafkaVersionTypeDef,
    ConfigurationInfoTypeDef,
    ConfigurationRevisionTypeDef,
    ConfigurationTypeDef,
    CreateClusterResponseTypeDef,
    CreateConfigurationResponseTypeDef,
    DeleteClusterResponseTypeDef,
    DeleteConfigurationResponseTypeDef,
    DescribeClusterOperationResponseTypeDef,
    DescribeClusterResponseTypeDef,
    DescribeConfigurationResponseTypeDef,
    DescribeConfigurationRevisionResponseTypeDef,
    EBSStorageInfoTypeDef,
    EncryptionAtRestTypeDef,
    EncryptionInfoTypeDef,
    EncryptionInTransitTypeDef,
    ErrorInfoTypeDef,
    FirehoseTypeDef,
    GetBootstrapBrokersResponseTypeDef,
    GetCompatibleKafkaVersionsResponseTypeDef,
    JmxExporterInfoTypeDef,
    JmxExporterTypeDef,
    KafkaVersionTypeDef,
    ListClusterOperationsResponseTypeDef,
    ListClustersResponseTypeDef,
    ListConfigurationRevisionsResponseTypeDef,
    ListConfigurationsResponseTypeDef,
    ListKafkaVersionsResponseTypeDef,
    ListNodesResponseTypeDef,
    ListTagsForResourceResponseTypeDef,
    LoggingInfoTypeDef,
    MutableClusterInfoTypeDef,
    NodeExporterInfoTypeDef,
    NodeExporterTypeDef,
    NodeInfoTypeDef,
    OpenMonitoringInfoTypeDef,
    OpenMonitoringTypeDef,
    PaginatorConfigTypeDef,
    PrometheusInfoTypeDef,
    PrometheusTypeDef,
    RebootBrokerResponseTypeDef,
    S3TypeDef,
    StateInfoTypeDef,
    StorageInfoTypeDef,
    TlsTypeDef,
    UpdateBrokerCountResponseTypeDef,
    UpdateBrokerStorageResponseTypeDef,
    UpdateClusterConfigurationResponseTypeDef,
    UpdateClusterKafkaVersionResponseTypeDef,
    UpdateConfigurationResponseTypeDef,
    UpdateMonitoringResponseTypeDef,
    ZookeeperNodeInfoTypeDef,
)


def get_structure() -> BrokerEBSVolumeInfoTypeDef:
    return {
      ...
    }
```
